Module run

Module run 

Structs

CapturedTargets
Captured target results for the required and optional comparison roles.
RunMetadata
Metadata supplied by an adapter when handing captured targets to core.

Functions

build_comparison_run
Build a persisted comparison run from adapter metadata and captured targets.