Structs
- Captured
Targets - Captured target results for the required and optional comparison roles.
- RunMetadata
- Metadata supplied by an adapter when handing captured targets to core.
Functions
- build_
comparison_ run - Build a persisted comparison run from adapter metadata and captured targets.